==> parcel-bundler-vue-1.6.3.tgz: package/lib/assets/JSAsset.js <==
'use strict';

var _from = require('babel-runtime/core-js/array/from');

var _from2 = _interopRequireDefault(_from);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _map = require('babel-runtime/core-js/map');

var _map2 = _interopRequireDefault(_map);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _require = require('babel-core'),
    BabelFile = _require.File;

var _traverse = require('babel-traverse').default;
var codeFrame = require('babel-code-frame');
var _collectDependencies = require('../visitors/dependencies');
var walk = require('babylon-walk');
var Asset = require('../Asset');
var babylon = require('babylon');
var insertGlobals = require('../visitors/globals');
var fsVisitor = require('../visitors/fs');
var babel = require('../transforms/babel');
var _generate = require('babel-generator').default;
var uglify = require('../transforms/uglify');
var SourceMap = require('../SourceMap');

var IMPORT_RE = /\b(?:import\b|export\b|require\s*\()/;
var GLOBAL_RE = /\b(?:process|__dirname|__filename|global|Buffer)\b/;
var FS_RE = /\breadFileSync\b/;
var SW_RE = /\bnavigator\s*\.\s*serviceWorker\s*\.\s*register\s*\(/;
var WORKER_RE = /\bnew\s*Worker\s*\(/;

var JSAsset = function (_Asset) {
  (0, _inherits3.default)(JSAsset, _Asset);

  function JSAsset(name, pkg, options) {
    (0, _classCallCheck3.default)(this, JSAsset);

    var _this = (0, _possibleConstructorReturn3.default)(this, (JSAsset.__proto__ || (0, _getPrototypeOf2.default)(JSAsset)).call(this, name, pkg, options));

    _this.type = 'js';
    _this.globals = new _map2.default();
    _this.isAstDirty = false;
    _this.isES6Module = false;
    _this.outputCode = null;
    _this.cacheData.env = {};
    return _this;
  }

  (0, _createClass3.default)(JSAsset, [{
    key: 'shouldInvalidate',
    value: function shouldInvalidate(cacheData) {
      for (var key in cacheData.env) {
        if (cacheData.env[key] !== process.env[key]) {
          return true;
        }
      }

      return false;
    }
  }, {
    key: 'mightHaveDependencies',
    value: function mightHaveDependencies() {
      return this.isAstDirty || !/.js$/.test(this.name) || IMPORT_RE.test(this.contents) || GLOBAL_RE.test(this.contents) || SW_RE.test(this.contents) || WORKER_RE.test(this.contents);
    }
  }, {
    key: 'getParserOptions',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        var options, _options$plugins, file;

        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                // Babylon options. We enable a few plugins by default.
                options = {
                  filename: this.name,
                  allowReturnOutsideFunction: true,
                  allowHashBang: true,
                  ecmaVersion: Infinity,
                  strictMode: false,
                  sourceType: 'module',
                  locations: true,
                  plugins: ['exportExtensions', 'dynamicImport']
                };

                // Check if there is a babel config file. If so, determine which parser plugins to enable

                _context.next = 3;
                return babel.getConfig(this);

              case 3:
                this.babelConfig = _context.sent;

                if (this.babelConfig) {
                  file = new BabelFile(this.babelConfig);

                  (_options$plugins = options.plugins).push.apply(_options$plugins, (0, _toConsumableArray3.default)(file.parserOpts.plugins));
                }

                return _context.abrupt('return', options);

              case 6:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function getParserOptions() {
        return _ref.apply(this, arguments);
      }

      return getParserOptions;
    }()
  }, {
    key: 'parse',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(code) {
        var options;
        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return this.getParserOptions();

              case 2:
                options = _context2.sent;
                return _context2.abrupt('return', babylon.parse(code, options));

              case 4:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function parse(_x) {
        return _ref2.apply(this, arguments);
      }

      return parse;
    }()
  }, {
    key: 'traverse',
    value: function traverse(visitor) {
      return _traverse(this.ast, visitor, null, this);
    }
  }, {
    key: 'traverseFast',
    value: function traverseFast(visitor) {
      return walk.simple(this.ast, visitor, this);
    }
  }, {
    key: 'collectDependencies',
    value: function collectDependencies() {
      walk.ancestor(this.ast, _collectDependencies, this);
    }
  }, {
    key: 'pretransform',
    value: function () {
      var _ref3 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee3() {
        return _regenerator2.default.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.next = 2;
                return babel(this);

              case 2:
              case 'end':
                return _context3.stop();
            }
          }
        }, _callee3, this);
      }));

      function pretransform() {
        return _ref3.apply(this, arguments);
      }

      return pretransform;
    }()
  }, {
    key: 'transform',
    value: function () {
      var _ref4 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee4() {
        return _regenerator2.default.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                if (!(this.options.target === 'browser')) {
                  _context4.next = 9;
                  break;
                }

                if (!(this.dependencies.has('fs') && FS_RE.test(this.contents))) {
                  _context4.next = 5;
                  break;
                }

                _context4.next = 4;
                return this.parseIfNeeded();

              case 4:
                this.traverse(fsVisitor);

              case 5:
                if (!GLOBAL_RE.test(this.contents)) {
                  _context4.next = 9;
                  break;
                }

                _context4.next = 8;
                return this.parseIfNeeded();

              case 8:
                walk.ancestor(this.ast, insertGlobals, this);

              case 9:
                if (!this.isES6Module) {
                  _context4.next = 12;
                  break;
                }

                _context4.next = 12;
                return babel(this);

              case 12:
                if (!this.options.minify) {
                  _context4.next = 15;
                  break;
                }

                _context4.next = 15;
                return uglify(this);

              case 15:
              case 'end':
                return _context4.stop();
            }
          }
        }, _callee4, this);
      }));

      function transform() {
        return _ref4.apply(this, arguments);
      }

      return transform;
    }()
  }, {
    key: 'generate',
    value: function () {
      var _ref5 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee5() {
        var code, opts, generated, rawMap;
        return _regenerator2.default.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                code = void 0;

                if (!this.isAstDirty) {
                  _context5.next = 16;
                  break;
                }

                opts = {
                  sourceMaps: this.options.sourceMaps,
                  sourceFileName: this.relativeName
                };
                generated = _generate(this.ast, opts, this.contents);

                if (!(this.options.sourceMaps && generated.rawMappings)) {
                  _context5.next = 13;
                  break;
                }

                rawMap = new SourceMap(generated.rawMappings, (0, _defineProperty3.default)({}, this.relativeName, this.contents));

                // Check if we already have a source map (e.g. from TypeScript or CoffeeScript)
                // In that case, we need to map the original source map to the babel generated one.

                if (!this.sourceMap) {
                  _context5.next = 12;
                  break;
                }

                _context5.next = 9;
                return new SourceMap().extendSourceMap(this.sourceMap, rawMap);

              case 9:
                this.sourceMap = _context5.sent;
                _context5.next = 13;
                break;

              case 12:
                this.sourceMap = rawMap;

              case 13:

                code = generated.code;
                _context5.next = 17;
                break;

              case 16:
                code = this.outputCode || this.contents;

              case 17:

                if (this.options.sourceMaps && !this.sourceMap) {
                  this.sourceMap = new SourceMap().generateEmptyMap(this.relativeName, this.contents);
                }

                if (!(this.globals.size > 0)) {
                  _context5.next = 26;
                  break;
                }

                code = (0, _from2.default)(this.globals.values()).join('\n') + '\n' + code;

                if (!this.options.sourceMaps) {
                  _context5.next = 26;
                  break;
                }

                if (this.sourceMap instanceof SourceMap) {
                  _context5.next = 25;
                  break;
                }

                _context5.next = 24;
                return new SourceMap().addMap(this.sourceMap);

              case 24:
                this.sourceMap = _context5.sent;

              case 25:

                this.sourceMap.offset(this.globals.size);

              case 26:
                return _context5.abrupt('return', {
                  js: code,
                  map: this.sourceMap
                });

              case 27:
              case 'end':
                return _context5.stop();
            }
          }
        }, _callee5, this);
      }));

      function generate() {
        return _ref5.apply(this, arguments);
      }

      return generate;
    }()
  }, {
    key: 'generateErrorMessage',
    value: function generateErrorMessage(err) {
      var loc = err.loc;
      if (loc) {
        err.codeFrame = codeFrame(this.contents, loc.line, loc.column + 1);
        err.highlightedCodeFrame = codeFrame(this.contents, loc.line, loc.column + 1, { highlightCode: true });
      }

      return err;
    }
  }]);
  return JSAsset;
}(Asset);

module.exports = JSAsset;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/assets/JSAsset.js <==
'use strict';

var _from = require('babel-runtime/core-js/array/from');

var _from2 = _interopRequireDefault(_from);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _map = require('babel-runtime/core-js/map');

var _map2 = _interopRequireDefault(_map);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _require = require('babel-core'),
    BabelFile = _require.File;

var _traverse = require('babel-traverse').default;
var codeFrame = require('babel-code-frame');
var _collectDependencies = require('../visitors/dependencies');
var walk = require('babylon-walk');
var Asset = require('../Asset');
var babylon = require('babylon');
var insertGlobals = require('../visitors/globals');
var fsVisitor = require('../visitors/fs');
var babel = require('../transforms/babel');
var _generate = require('babel-generator').default;
var uglify = require('../transforms/uglify');

var IMPORT_RE = /\b(?:import\b|export\b|require\s*\()/;
var GLOBAL_RE = /\b(?:process|__dirname|__filename|global|Buffer)\b/;
var FS_RE = /\breadFileSync\b/;
var SW_RE = /\bnavigator\s*\.\s*serviceWorker\s*\.\s*register\s*\(/;
var WORKER_RE = /\bnew\s*Worker\s*\(/;

var JSAsset = function (_Asset) {
  (0, _inherits3.default)(JSAsset, _Asset);

  function JSAsset(name, pkg, options) {
    (0, _classCallCheck3.default)(this, JSAsset);

    var _this = (0, _possibleConstructorReturn3.default)(this, (JSAsset.__proto__ || (0, _getPrototypeOf2.default)(JSAsset)).call(this, name, pkg, options));

    _this.type = 'js';
    _this.globals = new _map2.default();
    _this.isAstDirty = false;
    _this.isES6Module = false;
    _this.outputCode = null;
    _this.cacheData.env = {};
    return _this;
  }

  (0, _createClass3.default)(JSAsset, [{
    key: 'shouldInvalidate',
    value: function shouldInvalidate(cacheData) {
      for (var key in cacheData.env) {
        if (cacheData.env[key] !== process.env[key]) {
          return true;
        }
      }

      return false;
    }
  }, {
    key: 'mightHaveDependencies',
    value: function mightHaveDependencies() {
      return this.isAstDirty || !/.js$/.test(this.name) || IMPORT_RE.test(this.contents) || GLOBAL_RE.test(this.contents) || SW_RE.test(this.contents) || WORKER_RE.test(this.contents);
    }
  }, {
    key: 'getParserOptions',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        var options, _options$plugins, file;

        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                // Babylon options. We enable a few plugins by default.
                options = {
                  filename: this.name,
                  allowReturnOutsideFunction: true,
                  allowHashBang: true,
                  ecmaVersion: Infinity,
                  strictMode: false,
                  sourceType: 'module',
                  locations: true,
                  plugins: ['exportExtensions', 'dynamicImport']
                };

                // Check if there is a babel config file. If so, determine which parser plugins to enable

                _context.t0 = this.package && this.package.babel;

                if (_context.t0) {
                  _context.next = 6;
                  break;
                }

                _context.next = 5;
                return this.getConfig(['.babelrc', '.babelrc.js']);

              case 5:
                _context.t0 = _context.sent;

              case 6:
                this.babelConfig = _context.t0;

                if (this.babelConfig) {
                  file = new BabelFile({ filename: this.name });

                  (_options$plugins = options.plugins).push.apply(_options$plugins, (0, _toConsumableArray3.default)(file.parserOpts.plugins));
                }

                return _context.abrupt('return', options);

              case 9:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function getParserOptions() {
        return _ref.apply(this, arguments);
      }

      return getParserOptions;
    }()
  }, {
    key: 'parse',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(code) {
        var options;
        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return this.getParserOptions();

              case 2:
                options = _context2.sent;
                return _context2.abrupt('return', babylon.parse(code, options));

              case 4:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function parse(_x) {
        return _ref2.apply(this, arguments);
      }

      return parse;
    }()
  }, {
    key: 'traverse',
    value: function traverse(visitor) {
      return _traverse(this.ast, visitor, null, this);
    }
  }, {
    key: 'traverseFast',
    value: function traverseFast(visitor) {
      return walk.simple(this.ast, visitor, this);
    }
  }, {
    key: 'collectDependencies',
    value: function collectDependencies() {
      this.traverseFast(_collectDependencies);
    }
  }, {
    key: 'pretransform',
    value: function () {
      var _ref3 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee3() {
        return _regenerator2.default.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.next = 2;
                return babel(this);

              case 2:
              case 'end':
                return _context3.stop();
            }
          }
        }, _callee3, this);
      }));

      function pretransform() {
        return _ref3.apply(this, arguments);
      }

      return pretransform;
    }()
  }, {
    key: 'transform',
    value: function () {
      var _ref4 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee4() {
        return _regenerator2.default.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                if (!(this.dependencies.has('fs') && FS_RE.test(this.contents))) {
                  _context4.next = 4;
                  break;
                }

                _context4.next = 3;
                return this.parseIfNeeded();

              case 3:
                this.traverse(fsVisitor);

              case 4:
                if (!GLOBAL_RE.test(this.contents)) {
                  _context4.next = 8;
                  break;
                }

                _context4.next = 7;
                return this.parseIfNeeded();

              case 7:
                walk.ancestor(this.ast, insertGlobals, this);

              case 8:
                if (!this.isES6Module) {
                  _context4.next = 11;
                  break;
                }

                _context4.next = 11;
                return babel(this);

              case 11:
                if (!this.options.minify) {
                  _context4.next = 14;
                  break;
                }

                _context4.next = 14;
                return uglify(this);

              case 14:
              case 'end':
                return _context4.stop();
            }
          }
        }, _callee4, this);
      }));

      function transform() {
        return _ref4.apply(this, arguments);
      }

      return transform;
    }()
  }, {
    key: 'generate',
    value: function generate() {
      // TODO: source maps
      var code = this.isAstDirty ? _generate(this.ast).code : this.outputCode || this.contents;
      if (this.globals.size > 0) {
        code = (0, _from2.default)(this.globals.values()).join('\n') + '\n' + code;
      }

      return {
        js: code
      };
    }
  }, {
    key: 'generateErrorMessage',
    value: function generateErrorMessage(err) {
      var loc = err.loc;
      if (loc) {
        err.codeFrame = codeFrame(this.contents, loc.line, loc.column + 1);
        err.highlightedCodeFrame = codeFrame(this.contents, loc.line, loc.column + 1, { highlightCode: true });
      }

      return err;
    }
  }]);
  return JSAsset;
}(Asset);

module.exports = JSAsset;
